pub struct Scalar(pub(crate) U256);Expand description
Scalars are elements in the finite field modulo n.
Trait impls
Much of the important functionality is provided by traits from the ff crate:
Fieldrepresents elements of finite fields and provides:Field::randomgenerate a random field elementdouble,square, andinvertoperations- Bounds for
Add,Sub,Mul, andNeg(and*Assignequivalents) - Bounds for
ConditionallySelectablefrom thesubtlecrate
PrimeFieldrepresents elements of prime fields and provides:from_repr/to_reprfor converting field elements from/to big integers.MULTIPLICATIVE_GENERATORandROOT_OF_UNITYconstants.
Please see the documentation for the relevant traits for more information.
Tuple Fields
0: U256Implementations
Sourceimpl Scalar
impl Scalar
Sourcepub fn to_bytes(&self) -> FieldBytes
pub fn to_bytes(&self) -> FieldBytes
Returns the SEC1 encoding of this scalar.
Sourcepub const fn shr_vartime(&self, shift: u32) -> Scalar
pub const fn shr_vartime(&self, shift: u32) -> Scalar
Right shifts the scalar.
Note: not constant-time with respect to the shift parameter.
Sourcepub fn invert_vartime(&self) -> CtOption<Self>
pub fn invert_vartime(&self) -> CtOption<Self>
Compute [FieldElement] inversion: 1 / self in variable-time.
Sourceconst fn invert_unwrap(&self) -> Self
const fn invert_unwrap(&self) -> Self
Sourcepub const fn pow_vartime<const RHS_LIMBS: usize>(
&self,
exp: &Uint<RHS_LIMBS>,
) -> Self
pub const fn pow_vartime<const RHS_LIMBS: usize>( &self, exp: &Uint<RHS_LIMBS>, ) -> Self
Returns self^exp, where exp is a little-endian integer exponent.
This operation is variable time with respect to the exponent exp.
If the exponent is fixed, this operation is constant time.
Sourcepub const fn sqn_vartime(&self, n: usize) -> Self
pub const fn sqn_vartime(&self, n: usize) -> Self
Returns self^(2^n) mod p.
This operation is variable time with respect to the exponent n.
If the exponent is fixed, this operation is constant time.